Struct tensor_trade_stream::graphql::subscription::Payload
source · pub struct Payload { /* private fields */ }Expand description
Payload contains the raw data received back from a GraphQL subscription.
At the point of receiving data, the only known fields are { id, type };
what’s contained inside the payload field is unknown
until we attempt to deserialize it against a generated GraphQLQuery::ResponseData later.
Implementations