pub struct NewTransactionTV2;Trait Implementations
Sourceimpl Clone for NewTransactionTV2
impl Clone for NewTransactionTV2
Sourcefn clone(&self) -> NewTransactionTV2
fn clone(&self) -> NewTransactionTV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewTransactionTV2
impl Debug for NewTransactionTV2
Sourceimpl<'de> Deserialize<'de> for NewTransactionTV2
impl<'de> Deserialize<'de> for NewTransactionTV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl GraphQLQuery for NewTransactionTV2
impl GraphQLQuery for NewTransactionTV2
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for NewTransactionTV2
impl RefUnwindSafe for NewTransactionTV2
impl Send for NewTransactionTV2
impl Sync for NewTransactionTV2
impl Unpin for NewTransactionTV2
impl UnwindSafe for NewTransactionTV2