pub struct TswapOrderUpdate;Trait Implementations
Sourceimpl Clone for TswapOrderUpdate
impl Clone for TswapOrderUpdate
Sourcefn clone(&self) -> TswapOrderUpdate
fn clone(&self) -> TswapOrderUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TswapOrderUpdate
impl Debug for TswapOrderUpdate
Sourceimpl<'de> Deserialize<'de> for TswapOrderUpdate
impl<'de> Deserialize<'de> for TswapOrderUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl GraphQLQuery for TswapOrderUpdate
impl GraphQLQuery for TswapOrderUpdate
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for TswapOrderUpdate
impl RefUnwindSafe for TswapOrderUpdate
impl Send for TswapOrderUpdate
impl Sync for TswapOrderUpdate
impl Unpin for TswapOrderUpdate
impl UnwindSafe for TswapOrderUpdate