pub struct TswapOrderUpdateAll;Trait Implementations
Sourceimpl Clone for TswapOrderUpdateAll
impl Clone for TswapOrderUpdateAll
Sourcefn clone(&self) -> TswapOrderUpdateAll
fn clone(&self) -> TswapOrderUpdateAll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TswapOrderUpdateAll
impl Debug for TswapOrderUpdateAll
Sourceimpl<'de> Deserialize<'de> for TswapOrderUpdateAll
impl<'de> Deserialize<'de> for TswapOrderUpdateAll
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl GraphQLQuery for TswapOrderUpdateAll
impl GraphQLQuery for TswapOrderUpdateAll
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for TswapOrderUpdateAll
impl RefUnwindSafe for TswapOrderUpdateAll
impl Send for TswapOrderUpdateAll
impl Sync for TswapOrderUpdateAll
impl Unpin for TswapOrderUpdateAll
impl UnwindSafe for TswapOrderUpdateAll